GitHubIdenticonGenerator class

Core class for generating GitHub-style identicons

Constructors

GitHubIdenticonGenerator({required String seed, required double size, bool showGrid = false, Color? color})
Creates a GitHub identicon generator

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed String
final
showGrid bool
final
size double
final

Methods

generate() Future<Image>
Generates the identicon as a UI Image
generateImageBytes() Future<Uint8List>
Generates image bytes in PNG format
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited